define_field!() { /* proc-macro */ }Expand description
Define optimal field type and its corresponding config
If modulus fits into a native datatype, the resulting type is SmallFp<
define_field!() { /* proc-macro */ }Define optimal field type and its corresponding config
If modulus fits into a native datatype, the resulting type is SmallFp<