pub struct SmallFp<P: SmallFpConfig> {
pub value: P::T,
/* private fields */
}Expand description
Represents an element of the prime field F_p, where p == P::MODULUS.
This type can represent elements in any field of size up to 128 bits.
The arithmetic implementation is determined by the P: SmallFpConfig
parameter, which can be configured to use different backends
Fields
value: P::TImplementations