pub struct QuadExtField<P: QuadExtConfig> {
pub c0: P::BaseField,
pub c1: P::BaseField,
}Expand description
An element of a quadratic extension field F_p[X]/(X^2 - P::NONRESIDUE) is
represented as c0 + c1 * X, for c0, c1 in P::BaseField.
Fields
c0: P::BaseFieldCoefficient c0 in the representation of the field element c = c0 + c1 * X
c1: P::BaseFieldCoefficient c1 in the representation of the field element c = c0 + c1 * X
Implementations
Sourceimpl<P: Fp2Config> QuadExtField<Fp2ConfigWrapper<P>>
impl<P: Fp2Config> QuadExtField<Fp2ConfigWrapper<P>>
Sourcepub fn mul_assign_by_fp(&mut self, other: &P::Fp)
pub fn mul_assign_by_fp(&mut self, other: &P::Fp)
In-place multiply both coefficients c0 and c1 of self
by an element from Fp.
Examples
let c0: Fp = Fp::rand(&mut test_rng());
let c1: Fp = Fp::rand(&mut test_rng());
let mut ext_element: Fp2 = Fp2::new(c0, c1);
let base_field_element: Fp = Fp::rand(&mut test_rng());
ext_element.mul_assign_by_fp(&base_field_element);
assert_eq!(ext_element.c0, c0 * base_field_element);
assert_eq!(ext_element.c1, c1 * base_field_element);Sourceimpl<P: Fp4Config> QuadExtField<Fp4ConfigWrapper<P>>
impl<P: Fp4Config> QuadExtField<Fp4ConfigWrapper<P>>
Sourceimpl<P: Fp6Config> QuadExtField<Fp6ConfigWrapper<P>>
impl<P: Fp6Config> QuadExtField<Fp6ConfigWrapper<P>>
pub fn mul_by_034( &mut self, c0: &<P::Fp3Config as Fp3Config>::Fp, c3: &<P::Fp3Config as Fp3Config>::Fp, c4: &<P::Fp3Config as Fp3Config>::Fp, )
pub fn mul_by_014( &mut self, c0: &<P::Fp3Config as Fp3Config>::Fp, c1: &<P::Fp3Config as Fp3Config>::Fp, c4: &<P::Fp3Config as Fp3Config>::Fp, )
Sourceimpl<P: Fp12Config> QuadExtField<Fp12ConfigWrapper<P>>
impl<P: Fp12Config> QuadExtField<Fp12ConfigWrapper<P>>
pub fn mul_by_fp(&mut self, element: &<Self as Field>::BasePrimeField)
pub fn mul_by_034( &mut self, c0: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, c3: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, c4: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, )
pub fn mul_by_014( &mut self, c0: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, c1: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, c4: &Fp2<<<P as Fp12Config>::Fp6Config as Fp6Config>::Fp2Config>, )
Sourceimpl<P: QuadExtConfig> QuadExtField<P>
impl<P: QuadExtConfig> QuadExtField<P>
Sourcepub const fn new(c0: P::BaseField, c1: P::BaseField) -> Self
pub const fn new(c0: P::BaseField, c1: P::BaseField) -> Self
Create a new field element from coefficients c0 and c1,
so that the result is of the form c0 + c1 * X.
Examples
let c0: Fp = Fp::rand(&mut test_rng());
let c1: Fp = Fp::rand(&mut test_rng());
// `Fp2` a degree-2 extension over `Fp`.
let c: Fp2 = Fp2::new(c0, c1);Sourcepub fn conjugate_in_place(&mut self) -> &mut Self
pub fn conjugate_in_place(&mut self) -> &mut Self
This is only to be used when the element is known to be in the cyclotomic subgroup.
Sourcepub fn norm(&self) -> P::BaseField
pub fn norm(&self) -> P::BaseField
Norm of QuadExtField over P::BaseField:Norm(a) = a * a.conjugate().
This simplifies to: Norm(a) = a.x^2 - P::NON_RESIDUE * a.y^2.
This is alternatively expressed as Norm(a) = a^(1 + p).
Examples
let c: Fp2 = Fp2::rand(&mut test_rng());
let norm = c.norm();
// We now compute the norm using the `a * a.conjugate()` approach.
// A Frobenius map sends an element of `Fp2` to one of its p_th powers:
// `a.frobenius_map_in_place(1) -> a^p` and `a^p` is also `a`'s Galois conjugate.
let mut c_conjugate = c;
c_conjugate.frobenius_map_in_place(1);
let norm2 = c * c_conjugate;
// Computing the norm of an `Fp2` element should result in an element
// in BaseField `Fp`, i.e. `c1 == 0`
assert!(norm2.c1.is_zero());
assert_eq!(norm, norm2.c0);Sourcepub fn mul_assign_by_basefield(&mut self, element: &P::BaseField)
pub fn mul_assign_by_basefield(&mut self, element: &P::BaseField)
In-place multiply both coefficients c0 & c1 of the quadratic
extension field by an element from the base field.