Trait ark_ff::fields::FpParameters [−][src]
pub trait FpParameters: FftParameters { const MODULUS: Self::BigInt; const MODULUS_BITS: u32; const REPR_SHAVE_BITS: u32; const R: Self::BigInt; const R2: Self::BigInt; const INV: u64; const GENERATOR: Self::BigInt; const CAPACITY: u32; const T: Self::BigInt; const T_MINUS_ONE_DIV_TWO: Self::BigInt; const MODULUS_MINUS_ONE_DIV_TWO: Self::BigInt; }
A trait that defines parameters for a prime field.
Associated Constants
const MODULUS_BITS: u32[src]
const MODULUS_BITS: u32[src]The number of bits needed to represent the Self::MODULUS.
const REPR_SHAVE_BITS: u32[src]
const REPR_SHAVE_BITS: u32[src]The number of bits that must be shaved from the beginning of the representation when randomly sampling.
Let M be the power of 2^64 nearest to Self::MODULUS_BITS. Then
R = M % Self::MODULUS.
A multiplicative generator of the field.
Self::GENERATOR is an element having multiplicative order
Self::MODULUS - 1.
The number of bits that can be reliably stored.
(Should equal SELF::MODULUS_BITS - 1)
const T_MINUS_ONE_DIV_TWO: Self::BigInt[src]
const T_MINUS_ONE_DIV_TWO: Self::BigInt[src](t - 1) / 2
const MODULUS_MINUS_ONE_DIV_TWO: Self::BigInt[src]
const MODULUS_MINUS_ONE_DIV_TWO: Self::BigInt[src](Self::MODULUS - 1) / 2